## Automata

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/orome/automata-py.git/main/?urlpath=lab/tree/demo.ipynb)
[![Testing](https://github.com/orome/automata-py/actions/workflows/test-and-deploy.yml/badge.svg?branch=main)](https://github.com/orome/automata-py/actions/workflows/test-and-deploy.yml)
[![PyPi](https://img.shields.io/pypi/v/automata-py.svg)](https://pypi.python.org/pypi/automata-py)
[![PyPi Status](https://img.shields.io/pypi/status/automata-py.svg)](https://pypi.python.org/pypi/automata-py)
[![Supported Python](https://img.shields.io/pypi/pyversions/automata-py.svg)](https://pypi.python.org/pypi/automata-py)

A simple Python (3.10+) implementation aimed at simulating some cellular automata,
primarily those focused on by Stephan Wolfram, 
as I read along in [A New Kind of Science](https://www.wolframscience.com/nks/p315--the-intrinsic-generation-of-randomness/),
perpetually very much under construction. 

To play with the latest semi-stable version, 
[launch the demo notebook](https://mybinder.org/v2/gh/orome/automata-py.git/main/?urlpath=lab/tree/demo.ipynb) 
in Binder.

![Example display](https://raw.githubusercontent.com/orome/automata-py/main/docs/readme_eg.png)

A [related project](https://github.com/orome/turing-py) covers some basics of Turing Machines.
